# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pulpcore.client.pulp_container
from pulpcore.client.pulp_container.api.repositories_container_api import RepositoriesContainerApi  # noqa: E501
from pulpcore.client.pulp_container.rest import ApiException


class TestRepositoriesContainerApi(unittest.TestCase):
    """RepositoriesContainerApi unit test stubs"""

    def setUp(self):
        self.api = pulpcore.client.pulp_container.api.repositories_container_api.RepositoriesContainerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add(self):
        """Test case for add

        Add content  # noqa: E501
        """
        pass

    def test_build_image(self):
        """Test case for build_image

        Build an Image  # noqa: E501
        """
        pass

    def test_copy_manifests(self):
        """Test case for copy_manifests

        Copy manifests  # noqa: E501
        """
        pass

    def test_copy_tags(self):
        """Test case for copy_tags

        Copy tags  # noqa: E501
        """
        pass

    def test_create(self):
        """Test case for create

        Create a container repository  # noqa: E501
        """
        pass

    def test_delete(self):
        """Test case for delete

        Delete a container repository  # noqa: E501
        """
        pass

    def test_list(self):
        """Test case for list

        List container repositorys  # noqa: E501
        """
        pass

    def test_partial_update(self):
        """Test case for partial_update

        Update a container repository  # noqa: E501
        """
        pass

    def test_read(self):
        """Test case for read

        Inspect a container repository  # noqa: E501
        """
        pass

    def test_remove(self):
        """Test case for remove

        Remove content  # noqa: E501
        """
        pass

    def test_sync(self):
        """Test case for sync

        Sync from a remote  # noqa: E501
        """
        pass

    def test_tag(self):
        """Test case for tag

        Create a Tag  # noqa: E501
        """
        pass

    def test_untag(self):
        """Test case for untag

        Delete a tag  # noqa: E501
        """
        pass

    def test_update(self):
        """Test case for update

        Update a container repository  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
